Crate wacore_binary

Crate wacore_binary 

Re-exports

pub use attrs::AttrParser;
pub use attrs::AttrParserRef;
pub use error::BinaryError;
pub use error::Result;
pub use jid::BOT_SERVER;
pub use jid::BROADCAST_SERVER;
pub use jid::DEFAULT_USER_SERVER;
pub use jid::DeviceKey;
pub use jid::GROUP_SERVER;
pub use jid::HIDDEN_USER_SERVER;
pub use jid::HOSTED_LID_SERVER;
pub use jid::HOSTED_SERVER;
pub use jid::INTEROP_SERVER;
pub use jid::Jid;
pub use jid::JidExt;
pub use jid::JidRef;
pub use jid::LEGACY_USER_SERVER;
pub use jid::MESSENGER_SERVER;
pub use jid::MessageId;
pub use jid::MessageServerId;
pub use jid::NEWSLETTER_SERVER;
pub use jid::SERVER_JID;
pub use jid::STATUS_BROADCAST_USER;
pub use jid::Server;
pub use jid::push_jid_to_compact;
pub use jid::push_jid_to_string;
pub use marshal::marshal;
pub use marshal::marshal_auto;
pub use marshal::marshal_exact;
pub use marshal::marshal_ref;
pub use marshal::marshal_ref_auto;
pub use marshal::marshal_ref_exact;
pub use marshal::marshal_ref_to;
pub use marshal::marshal_ref_to_vec;
pub use marshal::marshal_to;
pub use marshal::marshal_to_vec;
pub use node::Attrs;
pub use node::Node;
pub use node::NodeContent;
pub use node::NodeContentRef;
pub use node::NodeRef;
pub use node::NodeStr;
pub use node::NodeValue;
pub use node::OwnedNodeRef;

Modules

attrs
builder
consts
encoder
error
jid
marshal
node
token
util
zlib_pool

Structs

CompactString
A CompactString is a compact string type that can be used almost anywhere a String or str can be used.