Encoder

Struct Encoder 

pub struct Encoder<'a, W: ByteWriter> { /* private fields */ }

Implementations

Source

impl<W: Write> Encoder<'static, IoByteWriter<W>>

pub fn new(writer: W) -> Result<Self>

Source

impl<'v> Encoder<'static, VecByteWriter<'v>>

pub fn new_vec(buffer: &'v mut Vec<u8>) -> Result<Self>

Source

impl<'a, W: ByteWriter> Encoder<'a, W>

pub fn write_bytes_with_len(&mut self, bytes: &[u8]) -> Result<()>

pub fn write_string(&mut self, s: &str) -> Result<()>

pub fn write_jid_ref(&mut self, jid: &JidRef<'_>) -> Result<()>

Write a JidRef directly without converting to string first. This avoids the allocation that would occur with jid.to_string().

pub fn write_jid_owned(&mut self, jid: &Jid) -> Result<()>

Write an owned Jid directly without converting to string first. This avoids the allocation that would occur with jid.to_string().

pub fn write_list_start(&mut self, len: usize) -> Result<()>

pub fn write_node<N: EncodeNode>(&mut self, node: &N) -> Result<()>

Write any node type (owned or borrowed) using the EncodeNode trait.