pub struct Encoder<'a, W: ByteWriter> { /* private fields */ }Implementations
Sourceimpl<'v> Encoder<'static, VecByteWriter<'v>>
impl<'v> Encoder<'static, VecByteWriter<'v>>
Sourceimpl<'a, W: ByteWriter> Encoder<'a, W>
impl<'a, W: ByteWriter> Encoder<'a, W>
pub fn write_bytes_with_len(&mut self, bytes: &[u8]) -> Result<()>
pub fn write_string(&mut self, s: &str) -> Result<()>
Sourcepub fn write_jid_ref(&mut self, jid: &JidRef<'_>) -> Result<()>
pub fn write_jid_ref(&mut self, jid: &JidRef<'_>) -> Result<()>
Write a JidRef directly without converting to string first.
This avoids the allocation that would occur with jid.to_string().
Sourcepub fn write_jid_owned(&mut self, jid: &Jid) -> Result<()>
pub fn write_jid_owned(&mut self, jid: &Jid) -> Result<()>
Write an owned Jid directly without converting to string first.
This avoids the allocation that would occur with jid.to_string().
pub fn write_list_start(&mut self, len: usize) -> Result<()>
Sourcepub fn write_node<N: EncodeNode>(&mut self, node: &N) -> Result<()>
pub fn write_node<N: EncodeNode>(&mut self, node: &N) -> Result<()>
Write any node type (owned or borrowed) using the EncodeNode trait.