Module node

Module node 

Structs

Node
NodeRef

Enums

NodeContent
NodeContentRef
ValueRef
A decoded attribute value that can be either a string or a structured JID. This avoids string allocation when decoding JID tokens - the JidRef is returned directly and only converted to a string when actually needed.

Type Aliases

Attrs
AttrsRef
NodeVec