pub struct NodeRef<'a> {
pub tag: NodeStr<'a>,
pub attrs: AttrsRef<'a>,
pub content: Option<Box<NodeContentRef<'a>>>,
}Fields
tag: NodeStr<'a>attrs: AttrsRef<'a>content: Option<Box<NodeContentRef<'a>>>Implementations
Sourceimpl<'a> NodeRef<'a>
impl<'a> NodeRef<'a>
pub fn new( tag: NodeStr<'a>, attrs: AttrsRef<'a>, content: Option<NodeContentRef<'a>>, ) -> Self
pub fn attrs(&self) -> AttrParserRef<'_>
pub fn children(&self) -> Option<&[NodeRef<'a>]>
pub fn get_attr(&self, key: &str) -> Option<&ValueRef<'a>>
pub fn attrs_iter(&self) -> impl Iterator<Item = (&NodeStr<'a>, &ValueRef<'a>)>
pub fn get_optional_child_by_tag(&self, tags: &[&str]) -> Option<&NodeRef<'a>>
pub fn get_children_by_tag<'b>(
&'b self,
tag: &'b str,
) -> impl Iterator<Item = &'b NodeRef<'a>>where
'a: 'b,
pub fn get_optional_child(&self, tag: &str) -> Option<&NodeRef<'a>>
Sourcepub fn content_as_string(&self) -> Option<CompactString>
pub fn content_as_string(&self) -> Option<CompactString>
Extract text content, handling both String and Bytes (lossy UTF-8).
Sourcepub fn content_bytes(&self) -> Option<&[u8]>
pub fn content_bytes(&self) -> Option<&[u8]>
Zero-copy byte content, if this node has Bytes content.
Sourcepub fn content_str(&self) -> Option<&str>
pub fn content_str(&self) -> Option<&str>
Zero-copy string content, if this node has String content.
Sourcepub fn content_nodes(&self) -> Option<&[NodeRef<'a>]>
pub fn content_nodes(&self) -> Option<&[NodeRef<'a>]>
Child nodes from content, if this node has Nodes content.
Alias for children().
pub fn to_owned(&self) -> Node